@@ -17,6 +17,10 @@ class RendererTestBase(TestCase):
         self.check_rst(out)
         return out
 
+    def conv_no_check(self, src, **kwargs):
+        out = convert(src, **kwargs)
+        return out
+
     def check_rst(self, rst):
         pub = Publisher(reader=None, parser=None, writer=None, settings=None,
                         source_class=io.StringInput,
@@ -138,6 +142,69 @@ class TestInlineMarkdown(RendererTestBase):
         self.assertEqual(
             out, '\nthis is a `link <http://example.com/>`_.\n')
 
+    def test_anonymous_link(self):
+        src = 'this is a [link](http://example.com/).'
+        out = self.conv(src, anonymous_references=True)
+        self.assertEqual(
+            out, '\nthis is a `link <http://example.com/>`__.\n')
+
+    def test_link_with_rel_link_enabled(self):
+        src = 'this is a [link](http://example.com/).'
+        out = self.conv_no_check(
+            src,
+            parse_relative_links=True
+        )
+        self.assertEqual(
+            out, '\nthis is a `link <http://example.com/>`_.\n')
+
+    def test_anonymous_link_with_rel_link_enabled(self):
+        src = 'this is a [link](http://example.com/).'
+        out = self.conv_no_check(
+            src,
+            parse_relative_links=True,
+            anonymous_references=True
+        )
+        self.assertEqual(
+            out, '\nthis is a `link <http://example.com/>`__.\n')
+
+    def test_anchor(self):
+        src = 'this is an [anchor](#anchor).'
+        out = self.conv_no_check(
+            src,
+            parse_relative_links=True
+        )
+        self.assertEqual(
+            out, '\nthis is an :ref:`anchor <anchor>`.\n')
+
+    def test_relative_link(self):
+        src = 'this is a [relative link](a_file.md).'
+        out = self.conv_no_check(
+            src,
+            parse_relative_links=True
+        )
+        self.assertEqual(
+            out, '\nthis is a :doc:`relative link <a_file>`.\n')
+
+    def test_relative_link_with_anchor(self):
+        src = 'this is a [relative link](a_file.md#anchor).'
+        out = self.conv_no_check(
+            src,
+            parse_relative_links=True
+        )
+        self.assertEqual(
+            out, '\nthis is a :doc:`relative link <a_file>`.\n')
+
+    def test_link_title(self):
+        src = 'this is a [link](http://example.com/ "example").'
+        out = self.conv(src)
+        self.assertEqual(
+            out,
+            '.. role:: raw-html-m2r(raw)\n'
+            '   :format: html\n\n\n'
+            'this is a :raw-html-m2r:'
+            '`<a href="http://example.com/" title="example">link</a>`.\n'
+        )
+
     def test_image_link(self):
         src = '[![Alt Text](image_taget_url)](link_target_url)'
         out = self.conv(src)
